==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Output/alsa/translations/alsa_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Output/alsa/translations/alsa_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="32"/>
        <source>ALSA Plugin</source>
        <translation>Greffon ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>About ALSA Output Plugin</source>
        <translation>À propos du greffon de sortie ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Greffon de sortie ALSA pour Qmmp</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="59"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Configuration du greffon ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Configuration du périphérique</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Périphérique audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation>Mixeur</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation>Carte de mixage : </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation>Périphérique de mixage : </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation>Configuration avancée</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation>Carte son</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation>Taille du tampon (ms) : </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation>Durée de la période (ms) : </translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation>Utiliser l&apos;accès mmap</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Utiliser la fonction snd_pcm_pause</translation>
    </message>
</context>
</TS>
